# T2S LUSA Dataset (Portuguese to English) - Test Set Only

This folder contains the manually reviewed test set of the T2S LUSA dataset, translated from European Portuguese into English.

## Description

T2S LUSA is a corpus of European Portuguese news articles from the Lusa News Agency, annotated for narrative structures and event-related information. It was developed as part of the Text2Story project to support event and narrative extraction in Portuguese.

## Dataset Availability

- This folder provides **only the test set (automatically aligned and manualy reviewed)**.
- The full T2S LUSA dataset, including training and validation splits, is available through the original publication and dataset repository.

To access the full dataset, please refer to:

**DOI:** [10.25747/ESFS-1P16](https://doi.org/10.25747/ESFS-1P16)

## Translation Details

- Original language: European Portuguese
- Translated to: English
- Translation and annotation alignment were performed using LinguAligner, with manual review applied to the test set to ensure quality.


## Reference

Nunes, Sérgio, Jorge, Alípio Mário, Amorim, Evelin, Sousa, Hugo, Leal, António, Silvano, Purificação Moura, Cantante, Inês, & Campos, Ricardo. (2024). **Text2Story Lusa: A Dataset for Narrative Analysis in European Portuguese News Articles**. *Proceedings of the 2024 Joint International Conference on Computational Linguistics, Language Resources and Evaluation (LREC-COLING 2024)*, 15773–15782. ELRA and ICCL. [https://aclanthology.org/2024.lrec-main.1370](https://aclanthology.org/2024.lrec-main.1370)

Silvano, P., Jorge, A., Leal, A., Amorim, E., Sousa, H., Cantante, I., Campos, R., & Nunes, S. (2023). **Text2Story Lusa Annotated Corpus [Data set]**. INESC TEC. [https://doi.org/10.25747/ESFS-1P16](https://doi.org/10.25747/ESFS-1P16)
